AstNode

Trait AstNode 

pub trait AstNode: Sized {
    // Required methods
    fn can_cast(kind: SyntaxKind) -> bool;
    fn cast(node: GdNode) -> Option<Self>;
    fn syntax(&self) -> &GdNode;
}
A typed node: a checked view over a red node of one SyntaxKind.

Required Methods

fn can_cast(kind: SyntaxKind) -> bool

Whether a node of kind can be viewed as Self.

fn cast(node: GdNode) -> Option<Self>

View node as Self, if its kind matches.

fn syntax(&self) -> &GdNode

The underlying red node.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors